﻿//
// Copyright (C) 2013 Chris Dziemborowicz
//
// This file is part of Orzeszek Transfer.
//
// Orzeszek Transfer is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Orzeszek Transfer is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

namespace OrzeszekTransfer
{
	public static class SharedFileManager
	{
		private static Dictionary<string, SharedFile> fileShares = new Dictionary<string, SharedFile>();

		public static SharedFile Add(string fullname)
		{
			FileInfo fi = new FileInfo(fullname);

			if (!fi.Exists)
				throw new FileNotFoundException();

			SharedFile fileShare = new SharedFile();

			fileShare.FullName = fi.FullName;
			fileShare.Name = fi.Name;
			fileShare.ID = RandomUtility.GetRandomString(Math.Max(Settings.Default.FileShareIdLength, 4));
			fileShare.Size = fi.Length;

			lock (fileShares)
			{
				while (fileShares.ContainsKey(fileShare.ID))
					fileShare.ID = RandomUtility.GetRandomString(Math.Max(Settings.Default.FileShareIdLength, 4));

				fileShares.Add(fileShare.ID, fileShare);
			}

			return fileShare;
		}

		public static SharedFile Get(string id)
		{
			lock (fileShares)
			{
				SharedFile sf = null;
				fileShares.TryGetValue(id, out sf);
				return sf;
			}
		}

		public static void Remove(SharedFile sf)
		{
			lock (fileShares)
				fileShares.Remove(sf.ID);

			sf.Dispose();
		}
	}
}